@@ -54,7 +54,7 @@ class pycrawl:
         #--------------------------------------------
         self.url = url
         page = self.agent.open(self.url, timeout=self.timeout)
-        html = page.read()
+        html = page.read().decode('utf-8', 'ignore')
         self.__update_params(html)
 
 
@@ -109,7 +109,7 @@ class pycrawl:
 
         # 送信
         self.agent.submit()
-        self.__update_params(self.agent.response().read().decode('utf-8'))
+        self.__update_params(self.agent.response().read().decode('utf-8', 'ignore'))
 
 
     def xpath(self, locator, single=False):
@@ -176,7 +176,7 @@ class pycrawl:
         #--------------------------------------------
         # タグ内の文字列を抽出
         #--------------------------------------------
-        return lxml.html.tostring(self.doc, encoding='utf-8').decode('utf-8')
+        return lxml.html.tostring(self.doc, encoding='utf-8').decode('utf-8', 'ignore')
 
 
     def __update_params(self, html):
